==> ejc-jlincome-impl-3.0.0-20240605.033657-144-sources.jar: com/ejianc/business/jlincome/bid/bean/TenderEvaluationEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标-投标文件评审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_evaluation")
public class TenderEvaluationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="engineering_id")
    private Long engineeringId; // 工程主键
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value="custom_name")
    private String customName; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value="org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value="org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value="product_type")
    private String productType; // 产品类型
    @TableField(value="product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 投标报价
    @TableField(value="bid_security_mny")
    private BigDecimal bidSecurityMny; // 投标保证金
    @TableField(value="review_date")
    private Date reviewDate; // 评审日期
    @TableField(value="bid_date")
    private Date bidDate; // 投标日期
    @TableField(value="plan_bid_open_date")
    private Date planBidOpenDate; // 预计开标日期
    @TableField(value="predict_delivery_date")
    private Date predictDeliveryDate; // 预计交货日期
    @TableField(value="date_num")
    private Integer dateNum; // 工期
    @TableField(value="profit_point")
    private BigDecimal profitPoint; // 利润点
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 成本金额
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 投标说明
    
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEngineeringId() {
        return engineeringId;
    }

    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public BigDecimal getBidSecurityMny() {
        return bidSecurityMny;
    }

    public void setBidSecurityMny(BigDecimal bidSecurityMny) {
        this.bidSecurityMny = bidSecurityMny;
    }
    public Date getReviewDate() {
        return reviewDate;
    }

    public void setReviewDate(Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public Date getPlanBidOpenDate() {
        return planBidOpenDate;
    }

    public void setPlanBidOpenDate(Date planBidOpenDate) {
        this.planBidOpenDate = planBidOpenDate;
    }
    public Date getPredictDeliveryDate() {
        return predictDeliveryDate;
    }

    public void setPredictDeliveryDate(Date predictDeliveryDate) {
        this.predictDeliveryDate = predictDeliveryDate;
    }
    public Integer getDateNum() {
        return dateNum;
    }

    public void setDateNum(Integer dateNum) {
        this.dateNum = dateNum;
    }
    public BigDecimal getProfitPoint() {
        return profitPoint;
    }

    public void setProfitPoint(BigDecimal profitPoint) {
        this.profitPoint = profitPoint;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jlincome-impl-3.0.0-20240930.032106-242-sources.jar: com/ejianc/business/jlincome/bid/bean/TenderEvaluationEntity.java <==
package com.ejianc.business.jlincome.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标-投标文件评审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_evaluation")
public class TenderEvaluationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="engineering_id")
    private Long engineeringId; // 工程主键
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value="custom_name")
    private String customName; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 组织/区域主键
    @TableField(value="org_name")
    private String orgName; // 组织名称/区域名称
    @TableField(value="org_code")
    private String orgCode; // 组织编码/区域编码
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类型
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value="product_type")
    private String productType; // 产品类型
    @TableField(value="product_type_name")
    private String productTypeName; // 产品类型名称
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 投标报价
    @TableField(value="bid_security_mny")
    private BigDecimal bidSecurityMny; // 投标保证金
    @TableField(value="review_date")
    private Date reviewDate; // 评审日期
    @TableField(value="bid_date")
    private Date bidDate; // 投标日期
    @TableField(value="plan_bid_open_date")
    private Date planBidOpenDate; // 预计开标日期
    @TableField(value="predict_delivery_date")
    private Date predictDeliveryDate; // 预计交货日期
    @TableField(value="date_num")
    private Integer dateNum; // 工期
    @TableField(value="profit_point")
    private BigDecimal profitPoint; // 利润点
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 成本金额
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 投标说明

    @TableField(value="sale_leader_id")
    private Long saleLeaderId; // 销售负责人
    @TableField(value="sale_leader_name")
    private String saleLeaderName; // 销售负责人名称
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEngineeringId() {
        return engineeringId;
    }

    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public BigDecimal getBidSecurityMny() {
        return bidSecurityMny;
    }

    public void setBidSecurityMny(BigDecimal bidSecurityMny) {
        this.bidSecurityMny = bidSecurityMny;
    }
    public Date getReviewDate() {
        return reviewDate;
    }

    public void setReviewDate(Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public Date getPlanBidOpenDate() {
        return planBidOpenDate;
    }

    public void setPlanBidOpenDate(Date planBidOpenDate) {
        this.planBidOpenDate = planBidOpenDate;
    }
    public Date getPredictDeliveryDate() {
        return predictDeliveryDate;
    }

    public void setPredictDeliveryDate(Date predictDeliveryDate) {
        this.predictDeliveryDate = predictDeliveryDate;
    }
    public Integer getDateNum() {
        return dateNum;
    }

    public void setDateNum(Integer dateNum) {
        this.dateNum = dateNum;
    }
    public BigDecimal getProfitPoint() {
        return profitPoint;
    }

    public void setProfitPoint(BigDecimal profitPoint) {
        this.profitPoint = profitPoint;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getSaleLeaderId() {
        return saleLeaderId;
    }

    public void setSaleLeaderId(Long saleLeaderId) {
        this.saleLeaderId = saleLeaderId;
    }

    public String getSaleLeaderName() {
        return saleLeaderName;
    }

    public void setSaleLeaderName(String saleLeaderName) {
        this.saleLeaderName = saleLeaderName;
    }
}
